==> jc-1.4.0.tar.gz: gnu/java/awt/peer/gtk/GThreadMutex.h <==
// class gnu.java.awt.peer.gtk.GThreadMutex

// class file dependencies
// @dep_class 3ddb53439566a009 gnu_java_awt_peer_gtk_GThreadMutex
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GThreadMutex_H_
#define _JC_gnu_java_awt_peer_gtk_GThreadMutex_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$sub_refs	_jc_gnu_java_awt_peer_gtk_GThreadMutex$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GThreadMutex$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$refs	_jc_gnu_java_awt_peer_gtk_GThreadMutex$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$nonrefs	_jc_gnu_java_awt_peer_gtk_GThreadMutex$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$object	_jc_gnu_java_awt_peer_gtk_GThreadMutex$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$vmethods	_jc_gnu_java_awt_peer_gtk_GThreadMutex$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$vtable	_jc_gnu_java_awt_peer_gtk_GThreadMutex$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$vtype	_jc_gnu_java_awt_peer_gtk_GThreadMutex$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GThreadMutex$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$object *);

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$vmethods {
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GThreadMutex$vmethods	gnu_java_awt_peer_gtk_GThreadMutex;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GThreadMutex$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$sub_refs {
	struct _jc_java_lang_Object$object	*lockForPotentialLockers;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$refs {
    _jc_gnu_java_awt_peer_gtk_GThreadMutex$sub_refs	gnu_java_awt_peer_gtk_GThreadMutex;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$sub_nonrefs {
	jint	volatile potentialLockers;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GThreadMutex$sub_nonrefs	gnu_java_awt_peer_gtk_GThreadMutex;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$object {
	_jc_gnu_java_awt_peer_gtk_GThreadMutex$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GThreadMutex$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GThreadMutex$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GThreadMutex$vtype _jc_gnu_java_awt_peer_gtk_GThreadMutex$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GThreadMutex, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GThreadMutex$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GThreadMutex_H_ */

==> jc-1.4.6.tar.gz: gnu/java/awt/peer/gtk/GThreadMutex.h <==
// class gnu.java.awt.peer.gtk.GThreadMutex

// class file dependencies
// @dep_class 3ddb53439566a009 gnu_java_awt_peer_gtk_GThreadMutex
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GThreadMutex_H_
#define _JC_gnu_java_awt_peer_gtk_GThreadMutex_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$sub_refs	_jc_gnu_java_awt_peer_gtk_GThreadMutex$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GThreadMutex$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$refs	_jc_gnu_java_awt_peer_gtk_GThreadMutex$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$nonrefs	_jc_gnu_java_awt_peer_gtk_GThreadMutex$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$object	_jc_gnu_java_awt_peer_gtk_GThreadMutex$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$vmethods	_jc_gnu_java_awt_peer_gtk_GThreadMutex$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$vtable	_jc_gnu_java_awt_peer_gtk_GThreadMutex$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$vtype	_jc_gnu_java_awt_peer_gtk_GThreadMutex$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GThreadMutex$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$vmethods {
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GThreadMutex$vmethods	gnu_java_awt_peer_gtk_GThreadMutex;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GThreadMutex$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$sub_refs {
	struct _jc_java_lang_Object$object	*lockForPotentialLockers;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$refs {
    _jc_gnu_java_awt_peer_gtk_GThreadMutex$sub_refs	gnu_java_awt_peer_gtk_GThreadMutex;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$sub_nonrefs {
	jint	volatile potentialLockers;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GThreadMutex$sub_nonrefs	gnu_java_awt_peer_gtk_GThreadMutex;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GThreadMutex$object {
	_jc_gnu_java_awt_peer_gtk_GThreadMutex$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GThreadMutex$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GThreadMutex$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GThreadMutex$vtype _jc_gnu_java_awt_peer_gtk_GThreadMutex$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GThreadMutex, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GThreadMutex$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GThreadMutex_H_ */
